@@ -2,8 +2,13 @@ package FBP::HtmlWindow;
 
 use Mouse;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 extends 'FBP::Window';
 
+has style => (
+	is  => 'ro',
+	isa => 'Str',
+);
+
 1;
